Getting started
===============

This library works with python>=3.7. Install it by executing \n
``python setup.py install`` \n
from the root directory.

For developing the usage of tox is encouraged. Run ``tox`` from the root directory in order to build the package,
these docs and perform several tests. You should not merge to master without tox having executed successfully!
